@@ -466,7 +466,7 @@ class LabelStudioMLManager(object):
 
     @classmethod
     def fetch(cls, project=None, label_config=None, force_reload=False, **kwargs):
-        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2'):
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=True):
             # TODO: Deprecated branch
             if cls.without_redis():
                 logger.debug('Fetch ' + project + ' from local directory')
@@ -544,7 +544,7 @@ class LabelStudioMLManager(object):
     def predict(
         cls, tasks, project=None, label_config=None, force_reload=False, try_fetch=True, **kwargs
     ):
-        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2'):
+        if not os.getenv('LABEL_STUDIO_ML_BACKEND_V2', default=True):
             if try_fetch:
                 m = cls.fetch(project, label_config, force_reload)
             else:
